@@ -109,6 +109,14 @@ class ModelInferenceClient:
         res.raise_for_status()
         response_data = res.json()
 
+        if errors := response_data["result"]["result"].get("errors", []):
+            print("An unhandled exception occurred in your handler:\n ")
+
+            for e in errors:
+                print(e)
+
+            return None
+
         try:
             result = ModelTypes.deserialize(
                 response_data["result"]["result"], output_schema
