@@ -28,6 +28,12 @@ class Model:
         if model_version_name == "":
             model_version_name = None
 
+        if org_name == "":
+            raise InvalidModelURI("invalid_model_route")
+
+        if model_name == "":
+            raise InvalidModelURI("invalid_model_route")
+
         self.org_name = org_name
         self.model_name = model_name
         self.model_version_name = model_version_name
