@@ -269,6 +269,8 @@ class DataframeType(ModelTypeSerializer):
                 obj = pd.DataFrame.from_dict(data)
             except ValueError:
                 raise InvalidTypeException("invalid_dataframe_dict")
+        elif isinstance(data, pd.DataFrame):
+            return data
         else:
             raise InvalidTypeException("invalid_dataframe")
 
